﻿#==============================================================================#
# (c) 2022 coolOrange s.r.l.                                                   #
#                                                                              #
# THIS SCRIPT/CODE IS PROVIDED "AS IS" WITHOUT WARRANTY OF ANY KIND, EITHER    #
# EXPRESSED OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES  #
# OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, OR NON-INFRINGEMENT.   #
#==============================================================================#

# Made for powerJobs Processor 23.0.1 and newer

# Required in the powerJobs Settings Dialog to determine the entity type for lifecycle state change triggers
# JobEntityType = FILE

#region Settings

# Name of the printer
$printerName = "Microsoft Print to PDF"

# How many copies are printed
$numberOfCopies = 1

# kPrintAllSheets, kPrintCurrentSheet
$printRange = "kPrintAllSheets"

# kPrintBestFitScale, kPrintCurrentWindow, kPrintCustomScale, kPrintFullScale
$scaleMode = "kPrintBestFitScale"

# kPrintDefaultColorMode, kPrintColorPalette, kPrintGrayScale
$colorMode = "kPrintDefaultColorMode"

# kPaperSizeA4, kPaperSizeA3, kPaperSizeA2, kPaperSizeA1, kPaperSizeA0
$paperSize = "kPaperSizeA4"

# kPortraitOrientation, kLandscapeOrientation
$orientation = "kPortraitOrientation"

# true, false
$allColorsAsBlack = $true

# To enable faster opening of released Inventor drawings without downloading and opening their model files set $true, otherwise $false
$openReleasedDrawingsFast = $true

#endregion


Write-Host ">> Print '$($file._Name)' with printer '$($printerName)'... >>"

if( @("idw","dwg") -notcontains $file._Extension ) {
	Write-Host "Files with extension: '$($file._Extension)' are not supported"
	return
}

$fastOpen = $openReleasedDrawingsFast -and $file._ReleasedRevision
$downloadedFiles = Save-VaultFile -File $file._FullPath -DownloadDirectory $workingDirectory -ExcludeChildren:$true -ExcludeLibraryContents:$true
$file = $downloadedFiles | Select-Object -First 1

$openResult = Open-Document -LocalFile $file.LocalPath -Options @{ FastOpen = $fastOpen }
if($openResult) {
	$Document = $openResult.Document.Instance
	$printManager = $Document.PrintManager
	$printManager.NumberOfCopies = $numberOfCopies
	$printManager.Printer = $printerName
	$printManager.PrintRange = [Inventor.PrintRangeEnum]$printRange
	$printManager.ScaleMode = [Inventor.PrintScaleModeEnum]$scaleMode
	$printManager.ColorMode = [Inventor.PrintColorModeEnum]$colorMode
	$printManager.PaperSize = [Inventor.PaperSizeEnum]$paperSize
	$printManager.allColorsAsBlack = $allColorsAsBlack
	$printManager.Orientation = [Inventor.PrintOrientationEnum]$orientation
	$printManager.SubmitPrint()

	$closeResult = Close-Document
}

if(-not $openResult) {
	throw("Failed to open document $($file.LocalPath)! Reason: $($openResult.ErrorMessage)")
}
if(-not $closeResult) {
	throw("Failed to close document $($file.LocalPath)! Reason: $($closeResult.ErrorMessage))")
}

Write-Host "<< Print '$($file._Name)' - DONE! <<"
